"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""

# -*- coding: utf-8 -*-
from constants import *


class HandleSeedDownWithVersion(object):

    def __call__(self, fn):

        def decorator(self):

            result = fn(self)
            unsupported_version_found = False
            if result != UNABLE_TO_CONNECT and result != UNSUPPORTED_VERSION:
                self.set_status_on()
                return result
            elif result == UNSUPPORTED_VERSION:
                unsupported_version_found = True

            seed = self.get_seed()
            for node in self._nodes:
                if node == seed:
                    continue
                ip, port = node.split(":")
                result = fn(self, ip, port)
                if result != UNABLE_TO_CONNECT and result != UNSUPPORTED_VERSION:
                    self.set_seed(node)
                    self.set_status_on()
                    return result
                elif result == UNSUPPORTED_VERSION:
                    unsupported_version_found = True

            if unsupported_version_found is False:
                self.set_status_off()
                return UNABLE_TO_CONNECT
            else:
                return UNSUPPORTED_VERSION

        return decorator
